imitation.policies package
==========================

Submodules
----------

imitation.policies.base module
------------------------------

.. automodule:: imitation.policies.base

imitation.policies.serialize module
-----------------------------------

.. automodule:: imitation.policies.serialize


Module contents
---------------

.. automodule:: imitation.policies
